@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calc.c
- * Version    : $Id: ipv6calc.c,v 1.33 2008/12/31 12:37:35 peter Exp $
- * Copyright  : 2001-2008 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: ipv6calc.c,v 1.35 2009/08/11 21:04:44 peter Exp $
+ * Copyright  : 2001-2009 by Peter Bieringer <pb (at) bieringer.de>
  * 
  * Information:
  *  Central program (main)
@@ -484,13 +484,13 @@ int main(int argc,char *argv[]) {
 			if (inputtype == FORMAT_undefined) {
 				inputtype = FORMAT_auto;
 			};
-			printhelp_outputtypes(inputtype);
+			printhelp_outputtypes(inputtype, formatoptions);
 			exit(EXIT_FAILURE);
 		} else if (inputtype == FORMAT_auto) {
-			printhelp_inputtypes();
+			printhelp_inputtypes(formatoptions);
 			exit(EXIT_FAILURE);
 		} else if (action == ACTION_auto) {
-			printhelp_actiontypes();
+			printhelp_actiontypes(formatoptions);
 			exit(EXIT_FAILURE);
 		};
 
@@ -605,6 +605,13 @@ int main(int argc,char *argv[]) {
 		};
 	};
 
+	/* auto set of output type*/
+	if (inputtype == FORMAT_revnibbles_int || inputtype == FORMAT_revnibbles_arpa) {
+		if ( outputtype == FORMAT_undefined ) {
+			outputtype = FORMAT_ipv6addr;
+		};
+	};
+
 	/* check formatoptions for validity */
 	for (i = 0; i < (int) (sizeof(ipv6calc_outputformatoptionmap) / sizeof(ipv6calc_outputformatoptionmap[0])); i++) {
 		if (outputtype != ipv6calc_outputformatoptionmap[i][0]) {
@@ -727,7 +734,7 @@ int main(int argc,char *argv[]) {
 	};
 
 	if (retval != 0) {
-		fprintf(stderr, "%s\n", resultstring);
+		if (strlen(resultstring) > 0) fprintf(stderr, "%s\n", resultstring);
 		exit(EXIT_FAILURE);
 	};
 	
