@@ -2,8 +2,8 @@
 #
 # Project    : ipv6calc
 # File       : test_ipv6calc.sh
-# Version    : $Id: test_ipv6calc.sh,v 1.13 2009/08/11 20:38:51 peter Exp $
-# Copyright  : 2001-2007 by Peter Bieringer <pb (at) bieringer.de>
+# Version    : $Id: test_ipv6calc.sh,v 1.16 2010/09/21 19:01:16 peter Exp $
+# Copyright  : 2001-2010 by Peter Bieringer <pb (at) bieringer.de>
 #
 # Test patterns for ipv6calc conversions
 
@@ -25,6 +25,7 @@ cat <<END | grep -v '^#'
 --in ipv6 --out revnibbles.arpa	3ffe::1/64				=0.0.0.0.0.0.0.0.0.0.0.0.e.f.f.3.ip6.arpa.
 -a --uppercase 3ffe::1/64						=0.0.0.0.0.0.0.0.0.0.0.0.E.F.F.3.IP6.ARPA.
 -a -u 3ffe::1/64							=0.0.0.0.0.0.0.0.0.0.0.0.E.F.F.3.IP6.ARPA.
+--out revnibbles.arpa abcd:1234:5678:abcd:1234:1234:1234:1234/125	=0.3.2.1.4.3.2.1.4.3.2.1.4.3.2.1.d.c.b.a.8.7.6.5.4.3.2.1.d.c.b.a.ip6.arpa. 
 ## to uncompressed
 --addr_to_compressed 3ffe:ffff:0100:f101:0000:0000:0000:0001		=3ffe:ffff:100:f101::1
 --in ipv6 --out ipv6 --printcompressed 3ffe:ffff:0100:f101:0000:0000:0000:0001 =3ffe:ffff:100:f101::1
@@ -48,7 +49,14 @@ cat <<END | grep -v '^#'
 --in ipv6 --out ipv6 --printcompressed --uppercase 0:0:0:0:0:ffff:129.144.52.38		=::FFFF:129.144.52.38
 ## uncompressed
 --addr_to_uncompressed 3ffe:ffff:100:f101::1				=3ffe:ffff:100:f101:0:0:0:1
---in ipv6 --out ipv6 --printuncompressed 3ffe:ffff:100:f101::1	=3ffe:ffff:100:f101:0:0:0:1
+--in ipv6 --out ipv6 --printuncompressed 3ffe:ffff:100:f101::1		=3ffe:ffff:100:f101:0:0:0:1
+--in ipv6 --out ipv6 --printuncompressed 2001:db8:0:cd30:1:2:3::	=2001:db8:0:cd30:1:2:3:0
+--in ipv6 --out ipv6 --printuncompressed 2001:db8:0:cd30:1::2		=2001:db8:0:cd30:1:0:0:2
+--in ipv6 --out ipv6 --printuncompressed 2001:db8:0:1::2:3		=2001:db8:0:1:0:0:2:3
+--in ipv6 --out ipv6 --printuncompressed 2001:db8:0:cd30:1:2::		=2001:db8:0:cd30:1:2:0:0
+--in ipv6 --out ipv6 --printuncompressed 2001:db8:0:cd30:1:2::4		=2001:db8:0:cd30:1:2:0:4
+--in ipv6 --out ipv6 --printuncompressed ::db8:0:cd30:1:2:3:4		=0:db8:0:cd30:1:2:3:4
+--in ipv6 --out ipv6 --printuncompressed ::1:cd30:1:2:3:4		=0:0:1:cd30:1:2:3:4
 --addr_to_uncompressed 3ffe:ffff:100:f101::1/64				=3ffe:ffff:100:f101:0:0:0:1/64
 --addr_to_uncompressed ::13.1.68.3					=0:0:0:0:0:0:13.1.68.3
 --addr_to_uncompressed ::013.01.068.0003				=0:0:0:0:0:0:13.1.68.3
@@ -132,7 +140,7 @@ testscenarios | while read line; do
 	fi
 
 	# extract result
-	command="`echo $line | awk -F= '{ print $1 }' | sed 's/\W*$//g'`"
+	command="`echo $line | awk -F= '{ print $1 }' | sed 's/ $//g'`"
 	result="`echo $line | awk -F= '{ print $2 }'`"
 	if [ -z "$result" -o -z "$command" ]; then
 		echo "Something is wrong in line '$line'"
@@ -154,9 +162,9 @@ testscenarios | while read line; do
 			exit 1
 		fi
 	fi
-done
+done || exit 1 
 
-echo "Run 'ipv6calc' input validation tests..."
+echo "Run 'ipv6calc' input validation tests...(empty input)"
 ./ipv6calc -m --in -? | while read inputformat; do
 	if echo $inputformat | grep -q '+'; then
 		echo "Test './ipv6calc -q --in $inputformat \"\" \"\"'"
@@ -173,6 +181,49 @@ echo "Run 'ipv6calc' input validation tests..."
 	fi
 done
 
+echo "Run 'ipv6calc' input validation tests...(too long input)"
+line="`perl -e 'print "x" x300'`"
+./ipv6calc -m --in -? | while read inputformat; do
+	if echo $inputformat | grep -q '+'; then
+		echo "Test './ipv6calc -q --in $inputformat \"$line\" \"$line\"'"
+		./ipv6calc -q --in $inputformat "$line" "$line"
+		retval=$?
+	else
+		echo "Test './ipv6calc -q --in $inputformat \"$line\"'"
+		./ipv6calc -q --in $inputformat "$line"
+		retval=$?
+	fi
+	if [ $retval -ne 0 -a $retval -ne 1 ]; then
+		echo "Error executing 'ipv6calc'!"
+		exit 1
+	fi
+done
+
+echo "Run 'ipv6calc' input validation tests...(strange input)"
+./ipv6calc -m --in -? | while read inputformat; do
+	case $inputformat in
+	    hex|ifinet6)
+		line="`perl -e 'print "x" x32'`"
+		;;
+	    *)
+		line="`perl -e 'print "x" x11'`"
+		;;
+	esac
+	if echo $inputformat | grep -q '+'; then
+		echo "Test './ipv6calc -q --in $inputformat \"$line\" \"$line\"'"
+		./ipv6calc -q --in $inputformat "$line" "$line"
+		retval=$?
+	else
+		echo "Test './ipv6calc -q --in $inputformat \"$line\"'"
+		./ipv6calc -q --in $inputformat "$line"
+		retval=$?
+	fi
+	if [ $retval -ne 0 -a $retval -ne 1 ]; then
+		echo "Error executing 'ipv6calc'!"
+		exit 1
+	fi
+done
+
 
 retval=$?
 if [ $retval -eq 0 ]; then
